@@ -5,6 +5,9 @@ use attributes ();
 use base 'Terse';
 use B 'svref_2object';
 
+our %HTTP;
+BEGIN { %HTTP = map { $_ => 1 } qw/get post put delete connect head options trace patch/; }
+
 sub MODIFY_CODE_ATTRIBUTES {
 	my ($package, $coderef, @attributes, @disallowed) = @_;
 	my $name = svref_2object($coderef)->GV->NAME;
@@ -30,10 +33,14 @@ sub PARSE_ATTRIBUTES {
 			$attr{params} = { eval $1 };
 		}
 		elsif ($attribute =~ m/^\s*([^\s\(]+)\s*\(([\s\'\"]*?)(.*)([\s\'\"]*?)\)/) {
-			$attr{$1} = $3;		
-		} 
+			my $k = lc($1);
+			$attr{$k} = $3;
+			if ($HTTP{$k}) {
+				$attr{req} = $3;
+			}	
+		}
 		else {
-			$attr{$attribute} = 1; 
+			$attr{lc($attribute)} = 1; 
 		}
 	}
 	return %attr;
@@ -107,7 +114,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.08
 
 =cut
 
@@ -121,7 +128,7 @@ Version 0.06
 		return 1;
 	}
 
-	sub auth_prevent :req(auth) :any {
+	sub auth_prevent :any(auth) {
 		return 0;
 	}
 
@@ -137,11 +144,11 @@ Version 0.06
 		... #2
 	}
 
-	sub purchase_post :req(purchase) :post {
+	sub purchase_post :post(purchase) {
 		... # 3
 	}
 
-	sub purchase_virtual_post :req(purchase) :post :params(virtual => 1) {
+	sub purchase_virtual_post :post(purchase) :params(virtual => 1) {
 		... # 4
 	}
 
